using Avalonia;
using Avalonia.Controls.ApplicationLifetimes;
using Avalonia.Data.Core.Plugins;
using Avalonia.Markup.Xaml;
using Example.Enums;
using Example.Models;
using Example.ViewModels;
using Example.Views;
using Microsoft.Extensions.DependencyInjection;
using System;

namespace Example;

public partial class App : Application
{
    /// <summary>
    /// Gets the <see cref="IServiceProvider"/> instance to resolve application services.
    /// </summary>
    private IServiceProvider _services;
    public override void Initialize()
    {
        _services = ConfigureServices();
        AvaloniaXamlLoader.Load(this);
    }


    public override void OnFrameworkInitializationCompleted()
    {
        // Line below is needed to remove Avalonia data validation.
        // Without this line you will get duplicate validations from both Avalonia and CT
        BindingPlugins.DataValidators.RemoveAt(0);

        if (ApplicationLifetime is IClassicDesktopStyleApplicationLifetime desktop)
        {
            _services.GetRequiredService<Status>().Value = StatusValue.ClassicDesktop;
            _services.GetRequiredService<MainWindow>().DataContext = _services.GetRequiredService<MainViewModel>();
            desktop.MainWindow = _services.GetRequiredService<MainWindow>();
        }
        else if (ApplicationLifetime is ISingleViewApplicationLifetime singleViewPlatform)
        {
            _services.GetRequiredService<Status>().Value = StatusValue.SingleViewApplication;
            _services.GetRequiredService<MainView>().DataContext = _services.GetRequiredService<MainViewModel>();
            singleViewPlatform.MainView = _services.GetRequiredService<MainView>();


        }


        base.OnFrameworkInitializationCompleted();
    }
    private static IServiceProvider ConfigureServices()
    {
        var services = new ServiceCollection();

        // Services


        // HttpClients
        //   services.AddHttpClient("itunes"); // IHttpClientFactory

        // ViewModels
        services.AddSingleton<Status>();
        services.AddSingleton<MainView>();
        services.AddSingleton<MainWindow>();
        services.AddTransient<MainViewModel>();

        return services.BuildServiceProvider();
    }
}