﻿using Avalonia.Controls;
using Avalonia.Platform.Storage;
using CommunityToolkit.Mvvm.Input;
using Example.Models;
using Example.Views;
using Microsoft.Extensions.DependencyInjection;
using System;
using System.Diagnostics.Metrics;
using System.Windows.Input;

namespace Example.ViewModels;

public class MainViewModel : ViewModelBase
{
    private string greeting;

    public string Greeting
    {
        get => greeting;
        set => SetProperty(ref greeting, value);
    }
    public ICommand HelloCommand { get; }
    private readonly IServiceProvider _serviceProvider;


    public MainViewModel(IServiceProvider serviceProvider)
    {
        Greeting = "Texte dans la fenêtre";
        HelloCommand = new RelayCommand(SayHello);
       _serviceProvider= serviceProvider;

    }

    private async void SayHello()
    {
        TopLevel? topLevel = null;
        switch (_serviceProvider.GetRequiredService<Status>().Value)
        {
            case Enums.StatusValue.ClassicDesktop:
                topLevel = TopLevel.GetTopLevel(_serviceProvider.GetRequiredService<MainWindow>());
                break;
            case Enums.StatusValue.SingleViewApplication:
                topLevel = TopLevel.GetTopLevel(_serviceProvider.GetRequiredService<MainView>());
                break;
   
        }


    // Start async operation to open the dialog.
    var files = await topLevel?.StorageProvider.OpenFilePickerAsync(new FilePickerOpenOptions
        {
            Title = "Open Text File",
            AllowMultiple = false
        });
        if (files.Count >= 1)
        {
            Greeting = files[0].Name;
        }
          
    }

}
